Welcome to Django-Qanda’s documentation! — django-qanda 0.1.0 documentation

### Navigation

- index
- next |
- django-qanda 0.1.0 documentation »

# Welcome to Django-Qanda’s documentation!

Qanda is a simple FAQ app for Django projects.

Here are the main features:

- Published questions can be made public, restricted to logged-in users, or only visible to site staff.
- Topics are self-hiding depending on the access level of the questions they contain.
- Qanda installs with a fully working set of templates so you can start playing straight away, and an example project is provided.

## Getting started

The first thing you’ll need to do is check out the installation guide and requirements.

If you’re familiar with installing Django apps then the installation is totally standard, with no additional dependencies.

## License

Django-Qanda is released under the MIT License.

## Contribute

- Issue Tracker: https://bitbucket.org/mhurt/django-qanda/issues
- Source Code: https://bitbucket.org/mhurt/django-qanda/

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- django-qanda 0.1.0 documentation »